==> V00.57.zip: tweet_live-V00.57/web/index.php <==
<?php
error_reporting(E_ALL);
ini_set('display_errors', '1');
/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
include_once './common.php';

/**
 * Do we already have a valid Access Token or need to go get one?
 */
if (!isset($_SESSION['TWITTER_ACCESS_TOKEN']) && isset($_GET['CONNECT']) ) {
    /**
     * Guess we need to go get one!
     */
    $token = $consumer->getRequestToken();
    $_SESSION['TWITTER_REQUEST_TOKEN'] = serialize($token);

    /**
     * Now redirect user to Twitter site so they can log in and
     * approve our access
     */
    $consumer->redirect();

}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>Polemic tweet - Live Video and Annotation</title>

    <!-- Framework CSS -->
    <link rel="stylesheet" href="res/blueprint/screen.css" type="text/css" media="screen, projection">
    <link rel="stylesheet" href="res/blueprint/print.css" type="text/css" media="print">
    <!--[if lt IE 8]><link rel="stylesheet" href="blueprint/ie.css" type="text/css" media="screen, projection"><![endif]-->

    <!-- Import fancy-type plugin for the sample page. -->
    
	<link rel="stylesheet" href="res/blueprint/plugins/fancy-type/screen.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" href="res/css/custom.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" href="res/css/tabs-slideshow.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" type="text/css" href="res/jquery.fancybox/fancybox/jquery.fancybox-1.3.4.css" media="screen">
	<link rel="stylesheet" type="text/css" href="res/niceforms/niceforms-custom.css" media="screen" >

	<!-- JAVASCRIPT --> 
	<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
	<!--<script type="text/javascript" src="res/jquery.tools/jquery.tools.min.js"></script>-->
	<script src="http://cdn.jquerytools.org/1.2.5/all/jquery.tools.min.js"></script>
	<script type="text/javascript" src="res/jquery.fancybox/fancybox/jquery.mousewheel-3.0.4.pack.js"></script>
	<script type="text/javascript" src="res/jquery.fancybox/fancybox/jquery.fancybox-1.3.4.pack.js"></script>
	<script type="text/javascript" src="res/niceforms/niceforms.js"></script>
	<script src="http://widgets.twimg.com/j/2/widget.js"></script>
	
	<!-- FONT -->
	<link href='http://fonts.googleapis.com/css?family=PT+Sans+Narrow&subset=latin' rel='stylesheet' type='text/css'>
	<link href='http://fonts.googleapis.com/css?family=PT+Sans&subset=latin' rel='stylesheet' type='text/css'>
	<link href='http://fonts.googleapis.com/css?family=Geo&subset=latin' rel='stylesheet' type='text/css'>

	<script type="text/javascript">	
	$(document).ready(function() {
		$(".loginbutton").click(function() {
			document.location.href="<?php URL_ROOT ?>?CONNECT=true";
		});
		$("#IDENTIFIER").click(function() {
			document.location.href="<?php URL_ROOT ?>?CONNECT=true";
		});
		$("#ACCES").click(function() {
			document.location.href="client.php";
		});
		$(".archivesVideoBox").mouseover(function() {
			//$(this).animate({'backgroundColor'});
			//$(this).css({'backgroundColor':'#d6d6d6'});
			$(this).css({'backgroundColor':'#fff'});
			$(this).cursor = "pointer";
		}).mouseout(function() {
			//$(this).css({'backgroundColor':'#f6f6f6'});
			$(this).css({'backgroundColor':'#f2f2f2'});
		});
		
		//<!-- SLIDER -->
		$(".slidetabs").tabs(".images > div", {
			effect: 'fade',
			rotate: false,
			interval: 4000,
			clickable:false
		}).slideshow();		
		
		$(".slidetabs").data("slideshow").play();
	});



		
	</script>
	<script type="text/javascript">
	
	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-23581291-1']);
	  _gaq.push(['_setDomainName', '.iri.centrepompidou.fr']);
	  _gaq.push(['_trackPageview']);
	
	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();
	
	</script>
  </head>
  <body>
    <div class="container">
      <img src="images/ENMI_2010_logo.gif" class="logo">
	  <ul class="menu"> 
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>?CONNECT=true" class="menuLink">
	  	<?php print $translate->_("S&apos;identifier"); ?></a></li>
	  <li class="menuUnderline"><a href="about.php" class="menuLink">
	  	<?php print $translate->_("A propos"); ?></a></li>
	  <li ><a href="mailto:contact@iri.centrepompidou.fr" class="menuLink" >
	  	<?php print $translate->_("Contact"); ?></a></li>
	  </ul>
	  
	  <ul class="menu lang" > 
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>?lang=ja_JP" class="menuLink" >
	       <img src='images/flag_jp.gif'<?php if($actual!="ja_JP"){echo("style='opacity: .5;'"); } ?> />
	        <?php print $translate->_("Japonais"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>?lang=fr" class="menuLink">
	       <img src='images/flag_fr.gif' <?php if($actual!="fr"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Français"); ?></a></li>
	  <li ><a href="<?php URL_ROOT ?>?lang=en" class="menuLink">
	       <img src='images/flag_en.gif' <?php if($actual!="en"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Anglais"); ?></a></li>
	  </ul>

	  <div class="introBox">

		  <div class="slider">
		  <!-- container for the slides -->
			<div class="images">
				<!-- first slide -->
				<div class="slides" style="background-image:url('images/slide0.gif');">
				<p class="slideTitle" >
					<?php print $translate->_("0. TitreSlide"); ?>
				</p>
				<p	style="padding-top:90px;padding-left:280px;width:520px;" class="slideText">
					<?php print $translate->_("0. TextSlide"); ?>
				</p>
				</div>
				<div class="slides" style="background-image:url('images/slide1.jpg');">
				<p class="slideTitle" >
					<?php print $translate->_("1. TitreSlide"); ?>
				</p>
				<br/><br/><br/><br/>
				<p style="width:400px;padding-left:400px;" class="slideText">
				<a class="button_b" href="#"  id="IDENTIFIER"><span>
				<?php print $translate->_("1.1 TextSlide"); ?></span></a>
				<?php print $translate->_("1.2 TextSlide"); ?>,<br/> <br/>
				<a class="button_w" href="#"  id="ACCES"><span>
				<?php print $translate->_("1.3 TextSlide"); ?></span></a> 
				</p>
				</div>
				<!-- second slide -->
				<div class="slides" style="background-image:url('images/slide2.jpg');">
				<p class="slideTitle" ><?php print $translate->_("2. TitreSlide"); ?></p>
				<br/><br/>
				<p	style="padding-top:90px;padding-left:280px;width:520px;" class="slideText">
				<?php print $translate->_("2. TextSlide"); ?>
				</p>
				</div>
				<!-- third slide -->
				<div class="slides" style="background-image:url('images/slide3.gif');">
				<p class="slideTitle" ><?php print $translate->_("3. TitreSlide"); ?></p>
				<br/><br/>
				<p style="width:400px;padding-right:400px;" class="slideText">
				<?php print $translate->_("3. TextSlide"); ?>
				</p>
				</div>
				<!-- fourth slide -->
				<div class="slides" style="background-image:url('/<?php print $C_REP ?>/images/slide4.jpg');">
				<p class="slideTitle" ><?php print $translate->_("4. TitreSlide"); ?></p>
				<br/><br/><br/>
				<p style="width:400px;padding-right:400px;" class="slideText">
				<?php print $translate->_("$C_abstract"); ?>
				 </p>

				 <a class="button_b" href="client.php"><span> <?php print $translate->_("4. Button"); ?></span> </a>
				 
				</div>
			</div>

			<!-- the tabs -->
			<div class="slidetabs">
				<a href="#"></a>
				<a href="#"></a>
				<a href="#"></a>
				<a href="#"></a>
				<a href="#"></a>
			</div>
		  </div>
		  
		<div class="intro">
			
		</div>
		  
	  </div>
	  <!-- --> 
	  <div class="archivesBox">
	  <div class="archivesBoxHeader"></div>
		<div class="archivesBoxContainer">
			<!-- -->
			<h3 class="archivesTitle"><?php print $translate->_("Archive Title :"); ?></h3>
			<!-- -->
			<div id="AVB3" class="archivesVideoBox">
				<a href="rsln/polemicaltimeline.php">
					<img src="images/tail_clay.jpg" width="270" height="150"/>
				</a>
				<div class="AVBtitle">Clay Shirky le net, le surplus cognitif</div>
				<div class="AVBtext">
					par <a href="http://www.rslnmag.fr/" target="_blank">RSLN</a> à Microsoft France
					<br/>le lundi 31 janvier 2011·| 08:30 - 10:30
				</div>
			</div>
			<!-- -->
			<div id="AVB2" class="archivesVideoBox">
				<a href="rsln-opendata/polemicaltimeline.php">
					<img src="images/tail_opendata.jpg" width="270" height="150"/>
				</a>
				<div class="AVBtitle">OPENDATA</div>
				<div class="AVBtext">
					par <a href="http://www.rslnmag.fr/" target="_blank">RSLN</a> à Microsoft France
					<br/>le jeudi 17 mars 2011 | 14:30 - 17:15
				</div>
			</div>
			<!-- -->
			<div id="AVB4" class="archivesVideoBox">
				<a href="rsln-mercedes-bunz/polemicaltimeline.php">
					<img src="images/tail_mercedes_bunz.jpg" width="270" height="150"/>
				</a>
				<div class="AVBtitle">Mercedes Bunz</div>
				<div class="AVBtext">
					par <a href="http://www.rslnmag.fr/" target="_blank">RSLN</a> à Microsoft France
					<br/>le jeudi 7 avril 2011 | 19:30 - 21:00
				</div>
			</div>
			
		</div>
		<div class="archivesBoxClear"></div>
		<div class="archivesBoxFooter"></div>
	  </div>
	 
      <div class="footer">
		<hr>
		<?php
			print $translate->_("footer text home"); 
			if (isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
					echo("| 	<a href='clear.php'  class='footerLink'>".$translate->_("D&eacute;connexion")."</a>");
			}
		 ?>
		  <input type="text" id="txt" size="3" style="visibility:hidden;"/>
	  </div>   
	

    </div>
	
	<!-- LIGHTBOX --> 
	<div style="display:none;">
		<div id="Aboutbox" >
		<div class="lightBorder">
			<div class="lightTitle">ENMI 2010</div>
			<div class="lightSubTitle">Annotation critique par tweet </div>
			<div class="lightDescription">À partir de cette interface ou de votre client twitter habituel, vous pouvez réagir en direct aux conférences en twittant. Vos tweets seront synchronisés avec l'enregistrement des conférences. Vous pourrez qualifier vos tweets en y intégrant la syntaxe ci-contre.
			</div>
			<div>
				<br/>
				<a class="button_b" href="#"  id="IDENTIFIER"><span>S'identifier</span></a> <br/><br/>
				<a class="button_w" href="#"  id="ACCES"><span>Libre accès</span></a> 
			</div>
		</div>
		</div>
	</div>

	
  </body>
</html>

==> V00.73.zip: tweet_live-V00.73/web/index.php <==
<?php
error_reporting(E_ALL);
ini_set('display_errors', '1');
/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */

include_once dirname(__FILE__).'/config.php';
include_once dirname(__FILE__).'/'.$C_default_rep.'/config.php';
include_once dirname(__FILE__).'/common.php';

/**
 * Do we already have a valid Access Token or need to go get one?
 */
if (!isset($_SESSION['TWITTER_ACCESS_TOKEN']) && isset($_GET['CONNECT']) ) {
    /**
     * Guess we need to go get one!
     */
    $token = $consumer->getRequestToken();
    $_SESSION['TWITTER_REQUEST_TOKEN'] = serialize($token);

    /**
     * Now redirect user to Twitter site so they can log in and
     * approve our access
     */
    $consumer->redirect();

}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>Polemic tweet - Live Video and Annotation</title>

    <!-- Framework CSS -->
    <link rel="stylesheet" href="res/blueprint/screen.css" type="text/css" media="screen, projection">
    <link rel="stylesheet" href="res/blueprint/print.css" type="text/css" media="print">
    <!--[if lt IE 8]><link rel="stylesheet" href="blueprint/ie.css" type="text/css" media="screen, projection"><![endif]-->

    <!-- Import fancy-type plugin for the sample page. -->
    
	<link rel="stylesheet" href="res/blueprint/plugins/fancy-type/screen.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" href="res/css/custom.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" href="res/css/tabs-slideshow.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" type="text/css" href="res/jquery.fancybox/fancybox/jquery.fancybox-1.3.4.css" media="screen">
	<link rel="stylesheet" type="text/css" href="res/niceforms/niceforms-custom.css" media="screen" >

	<!-- JAVASCRIPT --> 
	<script type="text/javascript" src="<?php echo(registry_url('jquery','js'));?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('jquery-tools','js'));?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('jquery-mousewheel','js'));?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('fancybox','js'));?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('niceforms','js'));?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('tw-widget','js'));?>"></script>
	
	<!-- FONT -->
	<link href='<?php echo(registry_url('PT-Sans_Narrow','font'));?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('PT-Sans','font'));?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('Geo','font'));?>' rel='stylesheet' type='text/css'>

	<script type="text/javascript">	
	$(document).ready(function() {
		$(".loginbutton").click(function() {
			document.location.href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php?CONNECT=true";
		});
		$("#IDENTIFIER").click(function() {
			document.location.href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php?CONNECT=true";
		});
		$("#ACCES").click(function() {
			document.location.href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php";
		});
		$(".archivesVideoBox").mouseover(function() {
			//$(this).animate({'backgroundColor'});
			//$(this).css({'backgroundColor':'#d6d6d6'});
			$(this).css({'backgroundColor':'#fff'});
			$(this).cursor = "pointer";
		}).mouseout(function() {
			//$(this).css({'backgroundColor':'#f6f6f6'});
			$(this).css({'backgroundColor':'#f2f2f2'});
		});
		
		//<!-- SLIDER -->
		$(".slidetabs").tabs(".images > div", {
			effect: 'fade',
			rotate: false,
			interval: 4000,
			clickable:false
		}).slideshow();		
		
		$(".slidetabs").data("slideshow").play();

		$(".scrollable").scrollable();
	});



		
	</script>
	<script type="text/javascript">
	
	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-23581291-1']);
	  _gaq.push(['_trackPageview']);
	
	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();
	
	</script>
  </head>
  <body>
    <div class="container">
      <img src="images/ENMI_2010_logo.gif" class="logo">
	  <ul class="menu"> 
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php?CONNECT=true" class="menuLink">
	  	<?php print $translate->_("S&apos;identifier"); ?></a></li>
	  <li class="menuUnderline"><a href="about.php" class="menuLink">
	  	<?php print $translate->_("A propos"); ?></a></li>
	  <li ><a href="mailto:contact@iri.centrepompidou.fr" class="menuLink" >
	  	<?php print $translate->_("Contact"); ?></a></li>
	  </ul>
	  <ul class="menu"> 
		  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>archives.php" class="menuLink">
		  	<?php print $translate->_("Archives"); ?></a></li>
	  </ul>
	  
	  <ul class="menu lang" > 
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>index.php?lang=ja_JP" class="menuLink" >
	       <img src='images/flag_jp.gif'<?php if($actual!="ja_JP"){echo("style='opacity: .5;'"); } ?> />
	        <?php print $translate->_("Japonais"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>index.php?lang=fr" class="menuLink">
	       <img src='images/flag_fr.gif' <?php if($actual!="fr"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Français"); ?></a></li>
	  <li ><a href="<?php echo(URL_ROOT); ?>index.php?lang=en" class="menuLink">
	       <img src='images/flag_en.gif' <?php if($actual!="en"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Anglais"); ?></a></li>
	  </ul>

	  <div class="introBox">

		  <div class="slider">
		  <!-- container for the slides -->
			<div class="images">
				<!-- first slide -->
				<div class="slides" style="background-image:url('images/slide0.gif');">
				<p class="slideTitle" >
					<?php print $translate->_("0. TitreSlide"); ?>
				</p>
				<p	style="padding-top:90px;padding-left:280px;width:520px;" class="slideText">
					<?php print $translate->_("0. TextSlide"); ?>
				</p>
				</div>
				<div class="slides" style="background-image:url('images/slide1.jpg');">
				<p class="slideTitle" >
					<?php print $translate->_("1. TitreSlide"); ?>
				</p>
				<br/><br/><br/><br/>
				<p style="width:400px;padding-left:400px;" class="slideText">
				<a class="button_b" href="#"  id="IDENTIFIER"><span>
				<?php print $translate->_("1.1 TextSlide"); ?></span></a>
				<?php print $translate->_("1.2 TextSlide"); ?>,<br/> <br/>
				<a class="button_w" href="#"  id="ACCES"><span>
				<?php print $translate->_("1.3 TextSlide"); ?></span></a> 
				</p>
				</div>
				<!-- second slide -->
				<div class="slides" style="background-image:url('images/slide2.jpg');">
				<p class="slideTitle" ><?php print $translate->_("2. TitreSlide"); ?></p>
				<br/><br/>
				<p	style="padding-top:90px;padding-left:280px;width:520px;" class="slideText">
				<?php print $translate->_("2. TextSlide"); ?>
				</p>
				</div>
				<!-- third slide -->
				<div class="slides" style="background-image:url('images/slide3.gif');">
				<p class="slideTitle" ><?php print $translate->_("3. TitreSlide"); ?></p>
				<br/><br/>
				<p style="width:400px;padding-right:400px;" class="slideText">
				<?php print $translate->_("3. TextSlide"); ?>
				</p>
				</div>
				<!-- fourth slide -->
				<div class="slides" style="background-image:url('<?php echo("$C_default_rep/$config[slide_background]"); ?>');">
				<p class="slideTitle" ><?php print $translate->_("4. TitreSlide"); ?></p>
				<br/><br/><br/>
				<p style="width:400px;padding-right:400px;" class="slideText">
				<?php print($translate->_($config['abstract'])); ?>
				 </p>

				 <a class="button_b" href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php"><span> <?php print $translate->_("4. Button"); ?></span> </a>
				 
				</div>
			</div>

			<!-- the tabs -->
			<div class="slidetabs">
				<a href="#"></a>
				<a href="#"></a>
				<a href="#"></a>
				<a href="#"></a>
				<a href="#"></a>
			</div>
		  </div>
		  
		<div class="intro">
			
		</div>
		  
	  </div>
	  <!-- --> 
	  <div class="archivesBox">
	  <div class="archivesBoxHeader"></div>

		<div class="archivesBoxContainer scrollable">
			<!-- -->
			<div class="archivesTitleActionsContainer">
				<div class="archivesTitleContainer"><h3 class="archivesTitle"><?php print $translate->_("Archive Title :"); ?></h3></div>
				<div class="archivesActionsContainer" id="actions">
		   			<a class="prev browse left disabled"></a>
		   			<a class="next browse right"></a>
				</div>
			</div>
			
			<!-- -->
			<div class="items">
			    <?php
			    $arch_list = array_reverse($archives_list);
			   	display_archives_list($arch_list, "archive_box_3 item", URL_ROOT, dirname(__FILE__)."/");
			    ?>
		    </div>
		</div>
		<div class="archivesBoxClear"></div>
		<div class="archivesBoxFooter"></div>
	  </div>
	 
      <div class="footer">
		<hr>
		<?php
			print $translate->_("footer text home"); 
			if (isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
					echo("| 	<a href='clear.php'  class='footerLink'>".$translate->_("D&eacute;connexion")."</a>");
			}
		 ?>
		  <input type="text" id="txt" size="3" style="visibility:hidden;"/>
	  </div>   
	

    </div>
	
	<!-- LIGHTBOX --> 
	<div style="display:none;">
		<div id="Aboutbox" >
		<div class="lightBorder">
			<div class="lightTitle">ENMI 2010</div>
			<div class="lightSubTitle">Annotation critique par tweet </div>
			<div class="lightDescription">À partir de cette interface ou de votre client twitter habituel, vous pouvez réagir en direct aux conférences en twittant. Vos tweets seront synchronisés avec l'enregistrement des conférences. Vous pourrez qualifier vos tweets en y intégrant la syntaxe ci-contre.
			</div>
			<div>
				<br/>
				<a class="button_b" href="#"  id="IDENTIFIER"><span>S'identifier</span></a> <br/><br/>
				<a class="button_w" href="#"  id="ACCES"><span>Libre accès</span></a> 
			</div>
		</div>
		</div>
	</div>

	
  </body>
</html>
